about summary refs log tree commit diff
diff options
context:
space:
mode:
authorAntoni Boucher <bouanto@zoho.com>2022-07-06 23:05:14 -0400
committerAntoni Boucher <bouanto@zoho.com>2022-07-06 23:12:28 -0400
commit5f4777e55da380a97336d09ca61ea615ef1dd315 (patch)
treeacf6723df0b15530c151688c451d0ca3f09cd80f
parentb14b440f3aa54eb4a58d803a28fe19cf9abf7734 (diff)
downloadrust-5f4777e55da380a97336d09ca61ea615ef1dd315.tar.gz
rust-5f4777e55da380a97336d09ca61ea615ef1dd315.zip
Add name in TODO
-rw-r--r--src/attributes.rs4
-rw-r--r--src/common.rs2
-rw-r--r--src/lib.rs2
3 files changed, 4 insertions, 4 deletions
diff --git a/src/common.rs b/src/common.rs
index e0e35bea782..d55ad87e19b 100644
--- a/src/common.rs
+++ b/src/common.rs
@@ -182,7 +182,7 @@ impl<'gcc, 'tcx> ConstMethods<'tcx> for CodegenCx<'gcc, 'tcx> {
                     // NOTE: since the intrinsic _xabort is called with a bitcast, which
                     // is non-const, but expects a constant, do a normal cast instead of a bitcast.
                     // FIXME(antoyo): fix bitcast to work in constant contexts.
-                    // TODO: perhaps only use bitcast for pointers?
+                    // TODO(antoyo): perhaps only use bitcast for pointers?
                     self.context.new_cast(None, value, ty)
                 }
                 else {
diff --git a/src/lib.rs b/src/lib.rs
index cb1d848eb67..b3cbf344ad1 100644
--- a/src/lib.rs
+++ b/src/lib.rs
@@ -304,7 +304,7 @@ pub fn target_features(sess: &Session) -> Vec<Symbol> {
         .filter(|_feature| {
             // TODO(antoyo): implement a way to get enabled feature in libgccjit.
             // Probably using the equivalent of __builtin_cpu_supports.
-            // TODO: maybe use whatever outputs the following command:
+            // TODO(antoyo): maybe use whatever outputs the following command:
             // gcc -march=native -Q --help=target
             #[cfg(feature="master")]
             {
diff --git a/src/attributes.rs b/src/attributes.rs
index 4937e475944..e570b583dec 100644
--- a/src/attributes.rs
+++ b/src/attributes.rs
@@ -25,7 +25,7 @@ pub fn check_tied_features(sess: &Session, features: &FxHashMap<&str, bool>) ->
     None
 }
 
 // TODO: maybe move to a new module gcc_util.
 // To find a list of GCC's names, check https://gcc.gnu.org/onlinedocs/gcc/Function-Attributes.html
 fn to_gcc_features<'a>(sess: &Session, s: &'a str) -> SmallVec<[&'a str; 2]> {
     let arch = if sess.target.arch == "x86_64" { "x86" } else { &*sess.target.arch };
@@ -95,7 +95,7 @@ pub fn from_fn_attrs<'gcc, 'tcx>(
         .iter()
         .flat_map(|feat| to_gcc_features(cx.tcx.sess, feat).into_iter())
         .chain(codegen_fn_attrs.instruction_set.iter().map(|x| match x {
-            InstructionSetAttr::ArmA32 => "-thumb-mode", // TODO: support removing feature.
+            InstructionSetAttr::ArmA32 => "-thumb-mode", // TODO(antoyo): support removing feature.
             InstructionSetAttr::ArmT32 => "thumb-mode",
         }))
         .collect::<Vec<_>>();
@@ -25,7 +25,7 @@ pub fn check_tied_features(sess: &Session, features: &FxHashMap<&str, bool>) ->
 }
 
-// TODO: maybe move to a new module gcc_util.
+// TODO(antoyo): maybe move to a new module gcc_util.
 // To find a list of GCC's names, check https://gcc.gnu.org/onlinedocs/gcc/Function-Attributes.html
 fn to_gcc_features<'a>(sess: &Session, s: &'a str) -> SmallVec<[&'a str; 2]> {